@@ -1,6 +1,3 @@
-from pkgutil import extend_path
-__path__ = extend_path(__path__, __name__)
-
 import abc
 import builtins
 import datetime
@@ -11,17 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-lambda-layer-curl",
-    "1.0.782",
+    "2.0.1",
     __name__[0:-6],
-    "cdk-lambda-layer-curl@1.0.782.jsii.tgz",
+    "cdk-lambda-layer-curl@2.0.1.jsii.tgz",
 )
 
 __all__ = [
